<?php
/**
 * Customizer active callbacks
 *
 * @package Graduate_Pro
 * @since Graduate Pro 1.0
 */

if ( ! function_exists( 'graduate_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'graduate_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'graduate_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'graduate_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'graduate_pro_is_top_bar_active' ) ) :
	/**
	 * Check if top bar is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_top_bar_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[top_bar_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_slider_active' ) ) :
	/**
	 * Check if slider is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_slider_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[slider_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_slider_demo_active' ) ) :
	/**
	 * Check if slider content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_slider_demo_active( $control ) {
		if ( graduate_pro_is_slider_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'graduate_pro_is_slider_page_content_active' ) ) :
	/**
	 * Check if slider content is page.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_slider_page_content_active( $control ) {
		if ( graduate_pro_is_slider_active( $control ) && 'page' == $control->manager->get_setting( 'graduate_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_slider_post_content_active' ) ) :
	/**
	 * Check if slider content is post.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_slider_post_content_active( $control ) {
		if ( graduate_pro_is_slider_active( $control ) && 'post' == $control->manager->get_setting( 'graduate_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_slider_category_content_active' ) ) :
	/**
	 * Check if slider content is category.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_slider_category_content_active( $control ) {
		if ( graduate_pro_is_slider_active( $control ) && 'category' == $control->manager->get_setting( 'graduate_pro_theme_options[slider_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_about_content_active' ) ) :
	/**
	 * Check if about content is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_about_content_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[about_content_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_about_content_page_active' ) ) :
	/**
	 * Check if about content is page.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_about_content_page_active( $control ) {
		if ( graduate_pro_is_about_content_active( $control ) && 'page' == $control->manager->get_setting( 'graduate_pro_theme_options[about_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_about_content_post_active' ) ) :
	/**
	 * Check if about content is post.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_about_content_post_active( $control ) {
		if ( graduate_pro_is_about_content_active( $control ) && 'post' == $control->manager->get_setting( 'graduate_pro_theme_options[about_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_about_content_not_demo' ) ) :
	/**
	 * Check if about content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function graduate_pro_is_about_content_not_demo( $control ) {
		if ( graduate_pro_is_about_content_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[about_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_information_section_active' ) ) :
	/**
	 * Check if information section is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_information_section_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[information_section_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_information_section_page_active' ) ) :
	/**
	 * Check if information section content is page.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_information_section_page_active( $control ) {
		if ( graduate_pro_is_information_section_active( $control ) && 'page' == $control->manager->get_setting( 'graduate_pro_theme_options[information_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_information_section_post_active' ) ) :
	/**
	 * Check if information section content is post.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_information_section_post_active( $control ) {
		if ( graduate_pro_is_information_section_active( $control ) && 'post' == $control->manager->get_setting( 'graduate_pro_theme_options[information_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_information_section_category_active' ) ) :
	/**
	 * Check if information section content is category.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_information_section_category_active( $control ) {
		if ( graduate_pro_is_information_section_active( $control ) && 'category' == $control->manager->get_setting( 'graduate_pro_theme_options[information_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_information_section_cat_list_active' ) ) :
	/**
	 * Check if information section content is category list.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_information_section_cat_list_active( $control ) {
		if ( graduate_pro_is_information_section_active( $control ) && 'cat-list' == $control->manager->get_setting( 'graduate_pro_theme_options[information_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_information_section_is_not_demo' ) ) :
	/**
	 * Check if information section content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_information_section_is_not_demo( $control ) {
		if ( graduate_pro_is_information_section_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[information_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_trending_courses_active' ) ) :
	/**
	 * Check if trending courses is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_trending_courses_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[trending_courses_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_trending_courses_category_active' ) ) :
	/**
	 * Check if trending courses content is category.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_trending_courses_category_active( $control ) {
		if ( graduate_pro_is_trending_courses_active( $control ) && 'category' == $control->manager->get_setting( 'graduate_pro_theme_options[trending_courses_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_trending_courses_not_demo' ) ) :
	/**
	 * Check if trending courses content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_trending_courses_not_demo( $control ) {
		if ( graduate_pro_is_trending_courses_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[trending_courses_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_trending_courses_taxonomy_active' ) ) :
	/**
	 * Check if trending courses content is custom taxonomy.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_trending_courses_taxonomy_active( $control ) {
		if ( graduate_pro_is_trending_courses_active( $control ) && 'category' != $control->manager->get_setting( 'graduate_pro_theme_options[trending_courses_content_type]' )->value() && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[trending_courses_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_top_destination_active' ) ) :
	/**
	 * Check if top destination is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_top_destination_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[top_destination_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_top_destination_category_active' ) ) :
	/**
	 * Check if top destination content is category.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_top_destination_category_active( $control ) {
		if ( graduate_pro_is_top_destination_active( $control ) && 'category' == $control->manager->get_setting( 'graduate_pro_theme_options[top_destination_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_top_destination_not_demo' ) ) :
	/**
	 * Check if top destination content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_top_destination_not_demo( $control ) {
		if ( graduate_pro_is_top_destination_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[top_destination_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_top_destination_taxonomy_active' ) ) :
	/**
	 * Check if top destination content is custom taxonomy.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_top_destination_taxonomy_active( $control ) {
		if ( graduate_pro_is_top_destination_active( $control ) && 'category' != $control->manager->get_setting( 'graduate_pro_theme_options[top_destination_content_type]' )->value() && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[top_destination_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_team_section_active' ) ) :
	/**
	 * Check if team section is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_team_section_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[team_section_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_team_section_category_active' ) ) :
	/**
	 * Check if team section content is category.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_team_section_category_active( $control ) {
		if ( graduate_pro_is_team_section_active( $control ) && 'category' == $control->manager->get_setting( 'graduate_pro_theme_options[team_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_team_section_not_demo' ) ) :
	/**
	 * Check if team section content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_team_section_not_demo( $control ) {
		if ( graduate_pro_is_team_section_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[team_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_team_section_taxonomy_active' ) ) :
	/**
	 * Check if team section content is custom taxonomy.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_team_section_taxonomy_active( $control ) {
		if ( graduate_pro_is_team_section_active( $control ) && 'category' != $control->manager->get_setting( 'graduate_pro_theme_options[team_section_content_type]' )->value() && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[team_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_map_section_active' ) ) :
	/**
	 * Check if map section is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_map_section_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[map_section_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_map_section_content_shortcode' ) ) :
	/**
	 * Check if map section is shortcode.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_map_section_content_shortcode( $control ) {
		if ( graduate_pro_is_map_section_active( $control ) && 'shortcode' == $control->manager->get_setting( 'graduate_pro_theme_options[map_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_map_section_content_embed' ) ) :
	/**
	 * Check if map section is embed.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_map_section_content_embed( $control ) {
		if ( graduate_pro_is_map_section_active( $control ) && 'embed' == $control->manager->get_setting( 'graduate_pro_theme_options[map_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_client_section_active' ) ) :
	/**
	 * Check if client section is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_client_section_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[client_section_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_client_section_custom_active' ) ) :
	/**
	 * Check if client section content is custom.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_client_section_custom_active( $control ) {
		if ( graduate_pro_is_client_section_active( $control ) && 'custom' == $control->manager->get_setting( 'graduate_pro_theme_options[client_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_client_section_page_active' ) ) :
	/**
	 * Check if client section content is page.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_client_section_page_active( $control ) {
		if ( graduate_pro_is_client_section_active( $control ) && 'page' == $control->manager->get_setting( 'graduate_pro_theme_options[client_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_client_section_not_demo' ) ) :
	/**
	 * Check if client section content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_client_section_not_demo( $control ) {
		if ( graduate_pro_is_client_section_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[client_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_featured_content_active' ) ) :
	/**
	 * Check if featured content is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_featured_content_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[featured_content_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_featured_content_page_active' ) ) :
	/**
	 * Check if featured content is page.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_featured_content_page_active( $control ) {
		if ( graduate_pro_is_featured_content_active( $control ) && 'page' == $control->manager->get_setting( 'graduate_pro_theme_options[featured_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_featured_content_post_active' ) ) :
	/**
	 * Check if featured content is post.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_featured_content_post_active( $control ) {
		if ( graduate_pro_is_featured_content_active( $control ) && 'post' == $control->manager->get_setting( 'graduate_pro_theme_options[featured_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_featured_content_category_active' ) ) :
	/**
	 * Check if featured content is category.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_featured_content_category_active( $control ) {
		if ( graduate_pro_is_featured_content_active( $control ) && 'category' == $control->manager->get_setting( 'graduate_pro_theme_options[featured_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_featured_content_cat_list_active' ) ) :
	/**
	 * Check if featured content is category list.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_featured_content_cat_list_active( $control ) {
		if ( graduate_pro_is_featured_content_active( $control ) && 'cat-list' == $control->manager->get_setting( 'graduate_pro_theme_options[featured_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_news_events_active' ) ) :
	/**
	 * Check if news & events is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_news_events_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[news_events_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_news_events_category_active' ) ) :
	/**
	 * Check if news & events content is category.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_news_events_category_active( $control ) {
		if ( graduate_pro_is_news_events_active( $control ) && 'category' == $control->manager->get_setting( 'graduate_pro_theme_options[news_events_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_news_events_not_demo' ) ) :
	/**
	 * Check if news & events content is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_news_events_not_demo( $control ) {
		if ( graduate_pro_is_news_events_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[news_events_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_news_events_taxonomy_active' ) ) :
	/**
	 * Check if news & events content is custom taxonomy.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_news_events_taxonomy_active( $control ) {
		if ( graduate_pro_is_news_events_active( $control ) && 'category' != $control->manager->get_setting( 'graduate_pro_theme_options[news_events_content_type]' )->value() && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[news_events_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_social_section_active' ) ) :
	/**
	 * Check if social section is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_social_section_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[social_section_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_social_section_custom' ) ) :
	/**
	 * Check if social section content type is custom.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_social_section_custom( $control ) {
		if ( graduate_pro_is_social_section_active( $control ) && 'custom' == $control->manager->get_setting( 'graduate_pro_theme_options[social_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_testinomial_active' ) ) :
	/**
	 * Check if testimonial is enabled.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_testinomial_active( $control ) {
		if ( 'disabled' != $control->manager->get_setting( 'graduate_pro_theme_options[testimonial_enable]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_testimonial_not_demo' ) ) :
	/**
	 * Check if testimonial content type is not demo.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_testimonial_not_demo( $control ) {
		if ( graduate_pro_is_testinomial_active( $control ) && 'demo' != $control->manager->get_setting( 'graduate_pro_theme_options[testimonial_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_testimonial_post' ) ) :
	/**
	 * Check if testimonial content type is post.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_testimonial_post( $control ) {
		if ( graduate_pro_is_testinomial_active( $control ) && 'post' == $control->manager->get_setting( 'graduate_pro_theme_options[testimonial_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'graduate_pro_is_testimonial_tp_testimonial' ) ) :
	/**
	 * Check if testimonial content type is testimonial.
	 *
	 * @since Graduate Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function graduate_pro_is_testimonial_tp_testimonial( $control ) {
		if ( graduate_pro_is_testinomial_active( $control ) && 'testimonial' == $control->manager->get_setting( 'graduate_pro_theme_options[testimonial_content_type]' )->value() )
			return true;

		return false;
	}
endif;