<?php
/**
* Contact page options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Contact page enable section
$wp_customize->add_section( 'graduate_pro_contact_page', array(
	'title'             => esc_html__( 'Contact Page','graduate-pro' ),
	'description'       => esc_html__( 'Contact Page options.', 'graduate-pro' ),
	'panel'             => 'graduate_pro_custom_page_options_panel'
) );

// Add Contact Page title.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_title]', array(
	'default'           => $options['contact_page_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_title]', array(
	'label'           	=> esc_html__( 'Title', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'text',
) );

// Add Contact Page description.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_description]', array(
	'default'           => $options['contact_page_description'],
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_description]', array(
	'label'           	=> esc_html__( 'Description', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'textarea',
) );

// Add Contact Page Contact Info Label
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_info_label]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new graduate_Pro_Note_Control( $wp_customize, 'graduate_pro_theme_options[contact_page_info_label]',
	array(
		'label'           => esc_html__( 'Contact Info', 'graduate-pro' ),
		'section'         => 'graduate_pro_contact_page',
) ) );

// Add Contact Page location.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_location]', array(
	'default'           => $options['contact_page_location'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_location]', array(
	'label'           	=> esc_html__( 'Location', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'text',
) );

// Add Contact Page phone.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_phone]', array(
	'default'           => $options['contact_page_phone'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_phone]', array(
	'label'           	=> esc_html__( 'Phone No', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'text',
) );

// Add Contact Page Po box.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_pobox]', array(
	'default'           => $options['contact_page_pobox'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_pobox]', array(
	'label'           	=> esc_html__( 'P.O Box', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'text',
) );

// Add Contact Page email.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_email]', array(
	'default'           => $options['contact_page_email'],
	'sanitize_callback' => 'sanitize_email'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_email]', array(
	'label'           	=> esc_html__( 'Email', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'email',
) );

// Add Contact Page Contact form Label
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_info_form]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new graduate_Pro_Note_Control( $wp_customize, 'graduate_pro_theme_options[contact_page_info_form]',
	array(
		'label'           => esc_html__( 'Contact Form Field', 'graduate-pro' ),
		'section'         => 'graduate_pro_contact_page',
) ) );

// Add Contact Page contact form.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_form]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_form]', array(
	'label'           	=> esc_html__( 'Contact Form Shortcode', 'graduate-pro' ),
	'description'       => esc_html__( 'Input shortcode from Contact Form 7 Plugin', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'text',
) );

// Add Contact Page map Label
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_map_label]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new graduate_Pro_Note_Control( $wp_customize, 'graduate_pro_theme_options[contact_page_map_label]',
	array(
		'label'           => esc_html__( 'Map', 'graduate-pro' ),
		'section'         => 'graduate_pro_contact_page',
) ) );

// Add Contact Page map.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_map]', array(
	'default'           => $options['contact_page_map'],
	'sanitize_callback' => 'graduate_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_map]', array(
	'label'           	=> esc_html__( 'Enable Map', 'graduate-pro' ),
	'description'       => esc_html__( 'Map will be rendered from front page map section.', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'checkbox',
) );

// Add Contact Page Social Label
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_social]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new graduate_Pro_Note_Control( $wp_customize, 'graduate_pro_theme_options[contact_page_social]',
	array(
		'label'         => esc_html__( 'Get Social', 'graduate-pro' ),
		'section'       => 'graduate_pro_contact_page',
) ) );

// Add Contact Page no of social.
$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_social_count]', array(
	'default'           => $options['contact_page_social_count'],
	'sanitize_callback' => 'absint',
	'validate_callback' => 'graduate_pro_validate_social_section_count',
) );

$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_social_count]', array(
	'label'           	=> esc_html__( 'No of Social Links', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_contact_page',
	'type'            	=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style'	=> 'width:100px'
		)
) );

for( $i = 1; $i <= $options['contact_page_social_count']; $i++ ) {
	// Add Contact Page phone.
	$wp_customize->add_setting( 'graduate_pro_theme_options[contact_page_social_' . $i . ']', array(
		'default'           => $options['contact_page_social_' . $i],
		'sanitize_callback' => 'esc_url'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[contact_page_social_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Social Link %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_contact_page',
		'type'            	=> 'url',
	) );
}

