<?php
/**
 * Theme Palace Theme Customizer.
 *
 * @package Graduate_Pro
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function graduate_pro_customize_register( $wp_customize ) {
	$options = graduate_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load customize partial functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Add panel for common theme options
	$wp_customize->add_panel( 'graduate_pro_custom_page_options_panel' , array(
	    'title'      => esc_html__( 'Custom Page Options','graduate-pro' ),
	    'description'=> esc_html__( 'Graduate Pro Custom Page Options.', 'graduate-pro' ),
	    'priority'   => 150,
	) );

	// contact page
	require get_template_directory() . '/inc/customizer/custom-template/contact-us.php';

	// Add panel for common theme options
	$wp_customize->add_panel( 'graduate_pro_section_options_panel' , array(
	    'title'      => esc_html__( 'Section Options','graduate-pro' ),
	    'description'=> esc_html__( 'Graduate Pro Section Options.', 'graduate-pro' ),
	    'priority'   => 150,
	) );

	// top bar
	require get_template_directory() . '/inc/customizer/sections/top-bar.php';

	// slider
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// about content
	require get_template_directory() . '/inc/customizer/sections/about-content.php';

	// information section
	require get_template_directory() . '/inc/customizer/sections/information-section.php';

	// trending courses
	require get_template_directory() . '/inc/customizer/sections/trending-courses.php';

	// top destination
	require get_template_directory() . '/inc/customizer/sections/top-destination.php';

	// team section
	require get_template_directory() . '/inc/customizer/sections/team-section.php';

	// map section
	require get_template_directory() . '/inc/customizer/sections/map-section.php';

	// testimonial section
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	// client section
	require get_template_directory() . '/inc/customizer/sections/client-section.php';

	// featured content
	require get_template_directory() . '/inc/customizer/sections/featured-content.php';

	// news & events
	require get_template_directory() . '/inc/customizer/sections/news-events.php';

	// social section
	require get_template_directory() . '/inc/customizer/sections/social-section.php';

	// Add panel for common theme options
	$wp_customize->add_panel( 'graduate_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','graduate-pro' ),
	    'description'=> esc_html__( 'Graduate Pro Theme Options.', 'graduate-pro' ),
	    'priority'   => 150,
	) );

	// theme color
	require get_template_directory() . '/inc/customizer/theme-options/theme-color.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// animation
	require get_template_directory() . '/inc/customizer/theme-options/animation.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load single layout
	require get_template_directory() . '/inc/customizer/theme-options/single-layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load excerpt option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load search option
	require get_template_directory() . '/inc/customizer/theme-options/search.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';
}
add_action( 'customize_register', 'graduate_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

if ( ! function_exists( 'graduate_pro_customize_preview_js' ) ) :
	/**
	 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
	 */
	function graduate_pro_customize_preview_js() {
		wp_enqueue_script( 'graduate_pro_customizer', get_template_directory_uri() . '/assets/js/customizer.min.js', array( 'customize-preview' ), '20151215', true );
	}
endif;
add_action( 'customize_preview_init', 'graduate_pro_customize_preview_js' );


if ( ! function_exists( 'graduate_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Graduate Pro 1.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function graduate_pro_reset_options() {
		$options = graduate_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'graduate_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'graduate_pro_reset_options' );
