<?php
/**
* Testimonial options
*
* @package Graduate_Pro
* @since Graduate Pro 1.0
*/

// Add Testimonial enable section
$wp_customize->add_section( 'graduate_pro_testimonial', array(
	'title'             => esc_html__( 'Testimonial','graduate-pro' ),
	'description'		=> esc_html__( 'Testimonial post type will be added as you install and activate TP Education Plugin.', 'graduate-pro' ),
	'panel'             => 'graduate_pro_section_options_panel'
) );

// Add Testimonial enable setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[testimonial_enable]', array(
	'default'           => $options['testimonial_enable'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[testimonial_enable]', array(
	'label'             => esc_html__( 'Enable on', 'graduate-pro' ),
	'section'           => 'graduate_pro_testimonial',
	'type'              => 'select',
	'choices'           => graduate_pro_enable_disable_options()
) );

// Add Testimonial title.
$wp_customize->add_setting( 'graduate_pro_theme_options[testimonial_title]', array(
	'default'           => $options['testimonial_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_testimonial',
	'type'            	=> 'text',
	'active_callback' 	=> 'graduate_pro_is_testinomial_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'graduate_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testimonials .entry-header h2.entry-title',
		'settings'            => 'graduate_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'graduate_pro_partial_testimonial_title',
    ) );
}

// Add Testimonial type setting and control.
$wp_customize->add_setting( 'graduate_pro_theme_options[testimonial_content_type]', array(
	'default'           => $options['testimonial_content_type'],
	'sanitize_callback' => 'graduate_pro_sanitize_select'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[testimonial_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_testimonial',
	'type'            	=> 'select',
	'active_callback' 	=> 'graduate_pro_is_testinomial_active',
	'choices'         	=> graduate_pro_testimonial_content_type()
) );

// Add Testimonial count.
$wp_customize->add_setting( 'graduate_pro_theme_options[testimonial_count]', array(
	'default'           => $options['testimonial_count'],
	'sanitize_callback' => 'graduate_pro_sanitize_number_range',
	'validate_callback' => 'graduate_pro_validate_no_of_testimonial'
) );

$wp_customize->add_control( 'graduate_pro_theme_options[testimonial_count]', array(
	'label'           	=> esc_html__( 'No of Testimonial', 'graduate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then referesh the page to see the change.', 'graduate-pro' ),
	'section'         	=> 'graduate_pro_testimonial',
	'type'            	=> 'number',
	'active_callback' 	=> 'graduate_pro_is_testimonial_not_demo',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style'	=> 'width:100px'
		)
) );

// Testimonial hr setting and control
$wp_customize->add_setting( 'graduate_pro_theme_options[testimonial_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new graduate_Pro_Customize_Horizontal_Line( $wp_customize, 'graduate_pro_theme_options[testimonial_hr]',
	array(
		'section'         => 'graduate_pro_testimonial',
		'active_callback' => 'graduate_pro_is_testimonial_not_demo',
		'type'			  => 'hr'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) {
	// Add Testimonial post id.
	$wp_customize->add_setting( 'graduate_pro_theme_options[testimonial_post_id_' . $i . ']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_number_range',
		'validate_callback' => 'graduate_pro_validate_post_id'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[testimonial_post_id_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Input Post ID %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_testimonial',
		'type'            	=> 'number',
		'active_callback' 	=> 'graduate_pro_is_testimonial_post',
		'input_attrs'		=> array(
			'min'	=> 1,
			'style'	=> 'width:100px'
			)
	) );

	// Add Testimonial post id.
	$wp_customize->add_setting( 'graduate_pro_theme_options[tp_testimonial_post_id_' . $i . ']', array(
		'sanitize_callback' => 'graduate_pro_sanitize_number_range',
		'validate_callback' => 'graduate_pro_validate_post_id'
	) );

	$wp_customize->add_control( 'graduate_pro_theme_options[tp_testimonial_post_id_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Testimonial Post ID %d', 'graduate-pro' ), $i ),
		'section'         	=> 'graduate_pro_testimonial',
		'type'            	=> 'number',
		'active_callback' 	=> 'graduate_pro_is_testimonial_tp_testimonial',
		'input_attrs'		=> array(
			'min'	=> 1,
			'style'	=> 'width:100px'
			)
	) );
}