<?php
/**
 * Graduate Pro post view count meta inclusion
 *
 * @package Graduate Pro
 * @since Graduate Pro 1.0
 */

if( ! function_exists( 'graduate_pro_get_post_views' ) ): 
	/**
	*
 	* Get any post views count
	*
	* @since Graduate Pro 1.0
	*
	* @param int $post_id Post id of current post.
 	* @return string String with views count
	*/
	function graduate_pro_get_post_views( $post_id ){
		//Set the name of the meta field.
	    $count_key = 'post_views_count';

		//Get value of the meta field
	    $count = get_post_meta($post_id, $count_key, true);

		//If meta field is empty
	    if( $count=='' ){
			//Delete all custom fields with the specified key from the specified post. 
	        delete_post_meta( $post_id, $count_key );

			//Add a custom (meta) field (Name/value)to the specified post.
	        add_post_meta( $post_id, $count_key, '0' );

	        return "0 View";
	    }
	    return $count . esc_html__(' Views', 'graduate-pro' );
	}
endif;

if( ! function_exists( 'graduate_pro_set_post_views' ) ): 
	/**
	*
 	* Set any post views
	*
	* @since Graduate Pro 1.0
	*
	* @param int $post_id Post id of current post.
 	* @return string String with views count
	*/
	function graduate_pro_set_post_views($post_id) {
		//Set the name of the meta field.
	    $count_key = 'post_views_count';

		//Get value of the meta field
	    $count = get_post_meta( $post_id, $count_key, true );

		//If meta field is empty
	    if( $count=='' ){
	        $count = 0;

			//Delete all custom fields with the specified key from the specified post. 
	        delete_post_meta( $post_id, $count_key );
	        
			//Add a custom (meta) field (Name/value)to the specified post.
	        add_post_meta( $post_id, $count_key, '0' );
	    }else{
	        $count++;
	        update_post_meta( $post_id, $count_key, $count );
	    }
	}
endif;
// Remove issues with prefetching adding extra views
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

if( ! function_exists( 'graduate_pro_track_post_views' ) ): 
	/**
	*
 	* Track if single page is loaded
	*
	* @since Graduate Pro 1.0
	*
	* @param int $post_id Post id of current post.
 	* @return string String with views count
	*/
	function graduate_pro_track_post_views ( $post_id ) {
	    if ( ! is_single() ) 
	    	return;
	    if ( empty ( $post_id) ) {
	        global $post;
	        $post_id = $post->ID;    
	    }
	    graduate_pro_set_post_views( $post_id );
	}
endif;
add_action( 'wp_head', 'graduate_pro_track_post_views');
